# ======================================================
# UnixGPT Default Values Collection
# ======================================================
#
# Default values used throughout the entire library.

# Library version
VERSION: str = "0.1.4"

# Default model for the library
DEFAULT_MODEL: str = "gpt-3.5-turbo"

# Current supported models
SUPPORTED_MODELS: list[str] = ["gpt-3.5-turbo"]
